===============================
Cointrader
===============================


.. image:: https://img.shields.io/pypi/v/cointrader.svg
        :target: https://pypi.python.org/pypi/cointrader

.. image:: https://img.shields.io/travis/toirl/cointrader.svg
        :target: https://travis-ci.org/toirl/cointrader

.. image:: https://readthedocs.org/projects/cointrader/badge/?version=latest
        :target: https://cointrader.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/toirl/cointrader/shield.svg
     :target: https://pyup.io/repos/github/toirl/cointrader/
     :alt: Updates


Cointrader is a CLI trading bot for crypto currencies on the Poloniex_ exchange.

* Free software: MIT license
* Documentation: https://cointrader.readthedocs.io.


Features
--------

* TODO


Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Poloniex: https://poloniex.com
.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

